==> haskell-dav-1.3.4-864-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-K2XuE4pVswpIBrTPDGe0P3
key:                  DAV-1.3.4-K2XuE4pVswpIBrTPDGe0P3
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  433f0672dc2279e3b5255f124dcb5a52
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-K2XuE4pVswpIBrTPDGe0P3
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM mtl-2.3.1 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y
    xml-conduit-1.9.1.4-4ApAZ67Z6lCGy52B3tehMj
    xml-hamlet-0.5.0.2-Kz7eXsy03Tr3cWMeJQANNr

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-865-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-IMk6O9UV0ae1rgxdW7GkLK
key:                  DAV-1.3.4-IMk6O9UV0ae1rgxdW7GkLK
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  86e207ce5de8e04435a5344aa9091a1e
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-IMk6O9UV0ae1rgxdW7GkLK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz exceptions-0.10.7
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB mtl-2.3.1 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt
    xml-hamlet-0.5.0.2-2sNf5wgkEygI6aAvX2PsOk

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
